pyxmpp2.interfaces.StreamFeatureHandler

Package pyxmpp2 :: Module interfaces :: Class StreamFeatureHandler |
[hide private]

# Class StreamFeatureHandler

Base class for stream feature handlers.

The handle_stream_features and make_stream_features should process and populate the `<stream::features/>` element as needed.

Other methods, decorated with the stream_element_handler decorated, will be called to handle matching stream element.

Nested Classes | [hide private]
| __metaclass__ Metaclass for defining Abstract Base Classes (ABCs).

Instance Methods | [hide private]
handle_stream_features(self, stream, features) Handle features announced by the stream peer. |
make_stream_features(self, stream, features) Update the features element announced by the stream. |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| __abstractmethods__ = ``frozenset([``])``
| _abc_cache = `<_weakrefset.WeakSet object at 0x85ce06c>`
| _abc_negative_cache = `<_weakrefset.WeakSet object at 0x85ce0ac>`
| _abc_negative_cache_version = `10`
| _abc_registry = `<_weakrefset.WeakSet object at 0x85cafec>`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### handle_stream_features(self, stream, features) |
Handle features announced by the stream peer. [initiator only] Parameters: `stream` (StreamBase) - the stream `features` (`ElementTree.Element`) - the features element just received Returns: StreamFeatureHandled instance if a feature was recognized and handled StreamFeatureNotHandled instance if a feature was recognized but not handled `None` if no feature was recognized

### make_stream_features(self, stream, features) |
Update the features element announced by the stream. [receiver only] Parameters: `stream` (StreamBase) - the stream `features` (`ElementTree.Element`) - the features element about to be sent